@@ -6,11 +6,9 @@ from django.http import HttpRequest
 from django.test import TestCase
 from django.test.client import Client
 from django.utils import simplejson as json
-import pkg_resources
 
 from lizard_map.adapter import Graph
 from lizard_map.adapter import parse_identifier_json
-from lizard_map.adapter import workspace_item_image_url
 from lizard_map.animation import AnimationSettings
 from lizard_map.daterange import default_start
 from lizard_map.daterange import default_end
@@ -23,7 +21,6 @@ from lizard_map.daterange import SESSION_DT_START
 from lizard_map.daterange import compute_and_store_start_end
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.daterange import current_period
-from lizard_map.daterange import set_date_range
 from lizard_map.dateperiods import ALL
 from lizard_map.dateperiods import YEAR
 from lizard_map.dateperiods import QUARTER
@@ -35,10 +32,10 @@ from lizard_map.dateperiods import fancy_period
 from lizard_map.mapnik_helper import database_settings
 from lizard_map.models import Color
 from lizard_map.models import Legend
-from lizard_map.models import Workspace
-from lizard_map.models import WorkspaceCollage
-from lizard_map.models import WorkspaceCollageSnippetGroup
-from lizard_map.models import WorkspaceItem
+from lizard_map.models import WorkspaceEdit
+from lizard_map.models import WorkspaceEditItem
+#from lizard_map.models import WorkspaceCollage
+#from lizard_map.models import WorkspaceCollageSnippetGroup
 from lizard_map.operations import AnchestorRegistration
 from lizard_map.operations import CycleError
 from lizard_map.operations import named_list
@@ -47,74 +44,61 @@ from lizard_map.operations import unique_list
 from lizard_map.utility import float_to_string
 from lizard_map.utility import short_string
 from lizard_map.workspace import WorkspaceItemAdapter
-from lizard_map.workspace import WorkspaceManager
+#from lizard_map.workspace import WorkspaceManager
 from lizard_map.templatetags import workspaces
 import lizard_map.admin
 import lizard_map.coordinates
+import lizard_map.daterange
 import lizard_map.layers
 import lizard_map.models
 import lizard_map.urls
 import lizard_map.views
 
 
-class WorkspaceManagerTest(TestCase):
+# New.
+from lizard_map.test_models import CollageTest
+from lizard_map.test_models import ExtentMixinTest
+from lizard_map.test_models import PeriodMixinTest
+from lizard_map.test_models import UserSessionMixinTest
+from lizard_map.test_models import WorkspaceEditTest
+from lizard_map.test_models import WorkspaceItemTest
+from lizard_map.test_models import WorkspaceLoadSaveTest
+from lizard_map.test_models import WorkspaceModelMixinTest
+from lizard_map.test_templatetags import WorkspacesTest
 
-    class MockRequest(object):
-        session = {}
-
-    def setUp(self):
-        mock_request = self.MockRequest()
-        self.workspace_manager = WorkspaceManager(
-            mock_request)
 
+class Mixins(TestCase):
+    # Satisfy pychecker
     def test_smoke(self):
-        """We use the WorkspaceManager to find and create our workspaces"""
-        self.assertTrue(self.workspace_manager)  # It exists.
-
-    def test_load_or_create(self):
-        workspace_groups = self.workspace_manager.load_or_create()
-        self.assertTrue(workspace_groups)
-
-    def test_load(self):
-        workspace_groups = self.workspace_manager.load_or_create()
-        self.assertTrue(workspace_groups)
-        self.workspace_manager.save_workspaces()
-        errors = self.workspace_manager.load_workspaces()
-        self.assertEqual(errors, 0)
-
-    def test_save(self):
-        workspace_groups = self.workspace_manager.load_or_create()
-        self.assertTrue(workspace_groups)
-        self.workspace_manager.save_workspaces()
-
-    def test_empty(self):
-        workspace_groups = self.workspace_manager.load_or_create()
-        self.assertTrue(workspace_groups)
-        self.workspace_manager.empty()
+        self.assertTrue(CollageTest)
+        self.assertTrue(ExtentMixinTest)
+        self.assertTrue(PeriodMixinTest)
+        self.assertTrue(UserSessionMixinTest)
+        self.assertTrue(WorkspaceEditTest)
+        self.assertTrue(WorkspaceItemTest)
+        self.assertTrue(WorkspaceLoadSaveTest)
+        self.assertTrue(WorkspaceModelMixinTest)
+        self.assertTrue(WorkspacesTest)
 
 
 class ViewsTest(TestCase):
     fixtures = ('lizard_map', )
 
-    class MockRequest(object):
-        session = {}
-
     def setUp(self):
         self.client = Client()
-        self.workspace = Workspace()
+        self.workspace = WorkspaceEdit(session_key='mock')
         self.workspace.save()
-        self.collage = WorkspaceCollage(workspace=self.workspace)
-        self.collage.save()
+        # self.collage = WorkspaceCollage(workspace=self.workspace)
+        # self.collage.save()
 
-    def test_homepage(self):
-        url = reverse('lizard_map_workspace',
-                      kwargs={'workspace_id': self.workspace.id})
-        response = self.client.get(url)
-        self.assertEqual(response.status_code, 200)
+    # def test_homepage(self):
+    #     url = reverse('lizard_map_workspace',
+    #                   kwargs={'workspace_id': self.workspace.id})
+    #     response = self.client.get(url)
+    #     self.assertEqual(response.status_code, 200)
 
-    def test_wms(self):
-        url = reverse('lizard_map_wms',
-                      kwargs={'workspace_id': self.workspace.id})
+    def test_workspace_edit_wms(self):
+        url = reverse('lizard_map_workspace_edit_wms')
         url += ('?LAYERS=basic&SERVICE=WMS&VERSION=1.1.1&REQUEST=GetMap&'
                 'STYLES=&EXCEPTIONS=application%2Fvnd.ogc.se_inimage&'
                 'FORMAT=image%2Fjpeg&SRS=EPSG%3A900913&'
@@ -124,27 +108,29 @@ class ViewsTest(TestCase):
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
-    def test_collage(self):
-        url = reverse('lizard_map.collage',
-                      kwargs={'collage_id': self.collage.id})
-        response = self.client.get(url)
-        self.assertEqual(response.status_code, 200)
+    # def test_collage(self):
+    #     url = reverse('lizard_map.collage',
+    #                   kwargs={'collage_id': self.collage.id})
+    #     response = self.client.get(url)
+    #     self.assertEqual(response.status_code, 200)
 
-    def test_collage_popup(self):
-        url = reverse('lizard_map.collage_popup',
-                      kwargs={'collage_id': self.collage.id})
-        response = self.client.get(url)
-        self.assertEqual(response.status_code, 200)
+    # def test_collage_popup(self):
+    #     url = reverse('lizard_map.collage_popup',
+    #                   kwargs={'collage_id': self.collage.id})
+    #     response = self.client.get(url)
+    #     self.assertEqual(response.status_code, 200)
 
     def test_search_coordinates(self):
         url = reverse('lizard_map.search_coordinates')
-        url += '?x=430987.5469813&y=6817896.448126&radius=100'
+        url += ('?x=430987.5469813&y=6817896.448126&radius=100&'
+                'user_workspace_id=%d' % self.workspace.id)
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
     def test_search_name(self):
         url = reverse('lizard_map.search_name')
-        url += '?x=430987.5469813&y=6817896.448126&radius=100'
+        url += ('?x=430987.5469813&y=6817896.448126&radius=100&'
+                'user_workspace_id=%d' % self.workspace.id)
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
@@ -171,233 +157,6 @@ class ViewsTest(TestCase):
              'left': '-14675', 'bottom': '6668977'})
 
 
-class WorkspaceTest(TestCase):
-
-    def test_workspace_contains_items(self):
-        """A workspace can contain workspace items"""
-        workspace1 = Workspace()
-        workspace1.save()
-        self.assertTrue(workspace1)
-        self.assertFalse(workspace1.workspace_items.all())  # Empty.
-        workspace_item1 = workspace1.workspace_items.create()
-        workspace_item2 = workspace1.workspace_items.create()
-        self.assertEquals(len(workspace1.workspace_items.all()), 2)
-        self.assertTrue(workspace_item1 in workspace1.workspace_items.all())
-        self.assertTrue(workspace_item2 in workspace1.workspace_items.all())
-
-    def test_name(self):
-        """A workspace always has a name.  It is 'My Workspace' by
-        default."""
-        workspace = Workspace()
-        self.assertEquals(workspace.name, u'My Workspace')
-
-    def test_representation(self):
-        workspace = Workspace()
-        workspace.save()
-        # No errors: fine.  As long as we return something.
-        self.assertTrue(unicode(workspace))
-
-    def test_absolute_url(self):
-        workspace = Workspace()
-        workspace.save()
-        # The initial version of this test asserted that the absolute URL ended
-        # with '/workspace/1', apparantly assuming that the new workspace would
-        # have id 1. However, that does not have to be the case.
-        expected_end = '/workspace/%d/' % workspace.id
-        self.assertTrue(workspace.get_absolute_url().endswith(expected_end))
-
-
-class WorkspaceClientTest(TestCase):
-
-    def setUp(self):
-        self.client = Client()
-
-    def test_workspace_item_add(self):
-        workspace = Workspace()
-        workspace.save()
-        url = reverse('lizard_map_workspace_item_add',
-                      kwargs={'workspace_id': str(workspace.id)})
-        params = {'name': 'test workspace_item',
-                  'adapter_class': 'test adapter_class',
-                  'adapter_layer_json': '{"json"}'}
-        self.client.post(url, params)
-        self.assertTrue(workspace.workspace_items.filter())
-
-    def test_workspace_item_reorder(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item1 = workspace.workspace_items.create()
-        workspace_item2 = workspace.workspace_items.create()
-        url = reverse('lizard_map_workspace_item_reorder',
-                      kwargs={'workspace_id': str(workspace.id)})
-        order = {'workspace-items[]': [
-                str(workspace_item2.id),
-                str(workspace_item1.id)]}
-        self.client.post(url, order)
-
-        self.assertEqual(workspace.workspace_items.all()[0], workspace_item2)
-        self.assertEqual(workspace.workspace_items.all()[1], workspace_item1)
-
-    def test_workspace_item_edit(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item1 = workspace.workspace_items.create(
-            name='test workspaceitem')
-
-        url = reverse('lizard_map_workspace_item_edit')
-        self.client.post(
-            url,
-            {'workspace_item_id': str(workspace_item1.id), 'visible': 'false'})
-        self.assertEqual(
-            WorkspaceItem.objects.get(name='test workspaceitem').visible,
-            False)
-        self.client.post(
-            url,
-            {'workspace_item_id': str(workspace_item1.id), 'visible': 'true'})
-        self.assertEqual(
-            WorkspaceItem.objects.get(name='test workspaceitem').visible,
-            True)
-
-    def test_workspace_item_delete(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item1 = workspace.workspace_items.create(
-            name='test workspaceitem')
-
-        url = reverse('lizard_map_workspace_item_delete')
-        self.client.post(
-            url,
-            {'object_id': str(workspace_item1.id)})
-        self.assertFalse(workspace.workspace_items.all())
-
-    def test_workspace_extent_temp(self):
-        """
-        Tests if the workspace extent does not crash (although the
-        content will be meaningless).
-        """
-        url = reverse('lizard_map_session_workspace_extent_temp')
-        result = self.client.get(url, {})
-        self.assertEqual(result.status_code, 200)
-
-    # Not testable without adapter
-    # def test_workspace_extent(self):
-    #     """
-    #     Tests if the workspace extent does not crash (although the
-    #     content will be meaningless).
-    #     """
-    #     workspace = Workspace()
-    #     workspace.save()
-    #     workspace_item1 = workspace.workspace_items.create(
-    #         name='test workspaceitem')
-    #     url = reverse('lizard_map_workspace_item_extent')
-    #     result = self.client.get(url, {
-    #             'workspace_item_id': workspace_item1.id})
-    #     self.assertEqual(result.status_code, 200)
-    #     self.assertTrue('north' in result.content)
-
-
-    # Not testable without adapter
-    # def test_workspace_item_image(self):
-    #     workspace = Workspace()
-    #     workspace.save()
-    #     workspace_item1 = workspace.workspace_items.create(
-    #         name='test workspaceitem')
-
-    #     url = reverse('lizard_map_workspace_item_image')
-    #     url += '?identifier={test_identifier}'
-    #     response = self.client.get(url)
-    #     self.assertEqual(response.status_code, 200)
-
-    # TODO: snippet stuff
-
-
-class WorkspaceItemTest(TestCase):
-
-    def test_has_adapter(self):
-        """A workspace item can point to a method that returns a layer."""
-        workspace_item = WorkspaceItem()
-        self.assertFalse(workspace_item.has_adapter())
-        workspace_item.adapter_class = 'todo'
-        self.assertTrue(workspace_item.has_adapter())
-
-    def test_entry_points_exist(self):
-        """There's at least one adapter entry point registered."""
-        self.assertTrue(list(pkg_resources.iter_entry_points(
-                    group='lizard_map.adapter_class')))
-
-    def test_entry_point_lookup(self):
-        """The string that identifies a method is looked up as a so-called
-        entry point."""
-        workspace_item = WorkspaceItem()
-        workspace_item.adapter_class = 'adapter_dummy'
-        workspace_item.adapter_layer_json = ("{}")
-        self.assertTrue(isinstance(
-                workspace_item.adapter,
-                lizard_map.layers.AdapterDummy))
-
-    def test_adapter_arguments(self):
-        """The layer method probably needs arguments. You can store them as a
-        json string."""
-        workspace_item = WorkspaceItem()
-        self.assertTrue(isinstance(workspace_item.adapter_layer_arguments,
-                                   dict))
-        self.assertFalse(len(workspace_item.adapter_layer_arguments))
-        workspace_item.adapter_layer_json = '{"bla": "yes"}'
-        self.assertEquals(workspace_item.adapter_layer_arguments['bla'],
-                          'yes')
-
-    def test_name(self):
-        """A workspace item always has a name.  It is blank by default,
-        though."""
-        workspace_item = WorkspaceItem()
-        self.assertEquals(workspace_item.name, '')
-        workspace_item2 = WorkspaceItem(name='bla')
-        self.assertEquals(workspace_item2.name, 'bla')
-
-    def test_representation(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item = workspace.workspace_items.create()
-        # No errors: fine.  As long as we return something.
-        self.assertTrue(unicode(workspace_item))
-
-    def test_delete_invalid_ws_item_1(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item = workspace.workspace_items.create(
-            adapter_class='adapter_dummy')
-        workspace_item.save()
-        self.assertTrue(isinstance(workspace_item.adapter,
-                                   lizard_map.layers.AdapterDummy))
-        workspace_item.adapter_layer_json = '{"invalid": "non existing"}bbb'
-        workspace_item.save()
-        # The workspace item should be deleted after .adapter() got an error.
-        self.assertEquals(workspace_item.adapter, None)
-        # Make sure the code doesn't hang in the __unicode__ after a deletion.
-        self.assertEquals(unicode(workspace_item), u"DELETED WORKSPACEITEM")
-
-    def test_delete_invalid_ws_item_2(self):
-        workspace = Workspace()
-        workspace.save()
-        workspace_item = workspace.workspace_items.create(
-            adapter_class='adapter_does_not_exist')
-        workspace_item.save()
-        # The workspace item should be deleted after .adapter() got an error.
-        self.assertEquals(workspace_item.adapter, None)
-        # Make sure the code doesn't hang in the __unicode__ after a deletion.
-        self.assertEquals(unicode(workspace_item), u"DELETED WORKSPACEITEM")
-
-
-class TestCollages(TestCase):
-
-    def test_creation(self):
-        workspace = Workspace()
-        workspace.save()  # save() because we need our generated id.
-        self.assertFalse(workspace.collages.all())
-        workspace.collages.create(name='user collage')
-        self.assertTrue(workspace.collages.all())
-
-
 class TestDateRange(TestCase):
     """Test daterange.py"""
 
@@ -414,7 +173,16 @@ class TestDateRange(TestCase):
 
     def _test_set_date_range(self, request):
 
-        set_date_range(self.request, now=self.today)
+        #set_date_range(self.request, now=self.today)
+        data = {'period': request.POST.get('period', None),
+                'dt_start': request.POST.get('dt_start', None),
+                'dt_end': request.POST.get('dt_end', None)}
+        form = lizard_map.forms.DateRangeForm(data)  # Fill in daterange
+        form.is_valid()  # it must succeed
+
+        view = lizard_map.views.DateRangeView()
+        view.request = request  # Manually put request in view
+        view.form_valid_action(form)  # Actually setting date range.
 
         # Get current period, dt_start, dt_end
         period = current_period(self.request)
@@ -451,6 +219,85 @@ class TestDateRange(TestCase):
         self.assertEquals(dt_start, self.today + PERIOD_DAYS[PERIOD_DAY][0])
         self.assertEquals(dt_end, self.today + PERIOD_DAYS[PERIOD_DAY][1])
 
+    def test_set_date_range2(self):
+        """Set custom date range, then retrieve it back"""
+        # Fake Post
+        self.request.method = 'POST'
+        dt_start_expected = datetime.datetime(2011, 5, 25)
+        dt_end_expected = datetime.datetime(2011, 5, 25, 23, 59, 59)
+        self.request.POST = {
+            'period': str(PERIOD_OTHER),
+            'dt_start': dt_start_expected,
+            'dt_end': dt_end_expected}
+        self.request.META = {}
+
+    #     period, dt_start, dt_end = self._test_set_date_range(self.request)
+    #     self.assertEquals(period, PERIOD_OTHER)
+    #     self.assertEquals(dt_start, dt_start_expected)
+    #     self.assertEquals(dt_end, dt_end_expected)
+    def test_set_date_range3(self):
+        """Set start date after end date: result must have dt_start<dt_end"""
+        timedelta_start = datetime.timedelta(days=20)
+        timedelta_end = datetime.timedelta(days=-15)
+
+        # Fake Post
+        self.request.method = 'POST'
+        self.request.POST = {
+            'period': str(PERIOD_OTHER),
+            'dt_start': self.today + timedelta_start,
+            'dt_end': self.today + timedelta_end}
+        self.request.META = {}
+
+        period, dt_start, dt_end = self._test_set_date_range(self.request)
+
+        self.assertEquals(period, PERIOD_OTHER)
+        self.assertTrue(dt_start < dt_end)
+
+    # # TODO: Check met Pieter
+    # def do_deltatime(
+    #     self, period_expected,
+    #     timedelta_start_expected, timedelta_end_expected):
+    #     """Easy testing deltatime_range."""
+
+    #     daterange = {'dt_start': self.today + timedelta_start_expected,
+    #                  'dt_end': self.today + timedelta_end_expected,
+    #                  'period': period_expected}
+    #     period, timedelta_start, timedelta_end = deltatime_range(
+    #         daterange, now=self.today)
+
+    #     # Test on day accuracy, because "almost_one_day" is added to end.
+    #     self.assertEquals(period, period_expected)
+    #     self.assertEquals(timedelta_start.days,
+    #                 timedelta_start_expected.days)
+    #     self.assertEquals(timedelta_end.days, timedelta_end_expected.days)
+
+    # def test_deltatime_range(self):
+    #     """Deltatime_range"""
+    #     timedelta_start_expected = datetime.timedelta(-1000)
+    #     timedelta_end_expected = datetime.timedelta(20)
+    #     period_expected = PERIOD_OTHER
+    #     self.do_deltatime(
+    #         period_expected,
+    #         timedelta_start_expected, timedelta_end_expected)
+
+    # def test_deltatime_range2(self):
+    #     """Deltatime_range"""
+    #     timedelta_start_expected = datetime.timedelta(-1)
+    #     timedelta_end_expected = datetime.timedelta(0)
+    #     period_expected = PERIOD_DAY
+    #     self.do_deltatime(
+    #         period_expected,
+    #         timedelta_start_expected, timedelta_end_expected)
+
+    # def test_deltatime_range3(self):
+    #     """Deltatime_range"""
+    #     timedelta_start_expected = datetime.timedelta(-365)
+    #     timedelta_end_expected = datetime.timedelta(0)
+    #     period_expected = PERIOD_YEAR
+    #     self.do_deltatime(
+    #         period_expected,
+    #         timedelta_start_expected, timedelta_end_expected)
+
 
 class TestAnimationSettings(TestCase):
     """Tests for animation.py."""
@@ -502,7 +349,7 @@ class TestAnimationSettings(TestCase):
         animation_settings = AnimationSettings(
             self.request, today=self.today)
         animation_settings.slider_position = self.date_start_days + 100
-        print current_start_end_dates(self.request)
+        # print current_start_end_dates(self.request)
         self.assertTrue(self.request.session.modified)
         self.assertEquals(
             animation_settings.slider_position, self.date_start_days + 100)
@@ -628,12 +475,6 @@ class UtilityTest(TestCase):
         self.assertTrue(parse_identifier_json(
                 '{%22testkey%22:%20%22testvalue%22}'))
 
-    def test_workspace_item_image_url(self):
-        workspace_item_id = 1  # Does not have to exist.
-        identifiers = [{}, {}]
-        self.assertTrue(workspace_item_image_url(
-                workspace_item_id, identifiers))
-
     def test_graph(self):
         start_date = datetime.datetime(2010, 7, 1)
         end_date = datetime.datetime(2010, 10, 1)
@@ -739,9 +580,9 @@ class UtilityTest(TestCase):
 class WorkspaceItemAdapterTest(TestCase):
 
     def setUp(self):
-        self.workspace = Workspace()
+        self.workspace = WorkspaceEdit()
         self.workspace.save()
-        workspace_item = WorkspaceItem(workspace=self.workspace)
+        workspace_item = WorkspaceEditItem(workspace=self.workspace)
         workspace_item.save()
         layer_arguments = {}
         self.adapter = WorkspaceItemAdapter(workspace_item, layer_arguments)
@@ -786,14 +627,6 @@ class WorkspaceItemAdapterTest(TestCase):
         identifiers = {}
         self.assertTrue(self.adapter.html_default(identifiers=identifiers))
 
-    def test_html_default_snippet_group(self):
-        workspace_collage = WorkspaceCollage(workspace=self.workspace)
-        workspace_collage.save()
-        snippet_group = WorkspaceCollageSnippetGroup(
-            workspace_collage=workspace_collage)
-        snippet_group.save()
-        self.assertTrue(self.adapter.html_default(snippet_group=snippet_group))
-
     def test_legend_object_default(self):
         self.adapter.legend_object_default('no_name')
 
@@ -1076,39 +909,41 @@ class CoordinatesTest(TestCase):
             lizard_map.coordinates.detect_prj(prj),
             lizard_map.coordinates.WGS84)
 
-    def test_map_settings(self):
-        """
-        Test MapSettings class. Nothing in settings.py, so revert to
-        default google projection and srid.
-        """
-        map_settings = lizard_map.coordinates.MapSettings()
+    # Jack *thinks* map_settings could be deleted
 
-        self.assertTrue(map_settings.mapnik_projection(),
-                        lizard_map.coordinates.GOOGLE)
-        self.assertTrue(map_settings.srid, 900913)
+    # def test_map_settings(self):
+    #     """
+    #     Test MapSettings class. Nothing in settings.py, so revert to
+    #     default google projection and srid.
+    #     """
+    #     map_settings = lizard_map.coordinates.MapSettings()
 
-    def test_map_settings2(self):
-        """
-        Test custom settings for MapSettings.
-        """
+    #     self.assertTrue(map_settings.mapnik_projection(),
+    #                     lizard_map.coordinates.GOOGLE)
+    #     self.assertTrue(map_settings.srid, 900913)
 
-        MAP_SETTINGS = {
-            'base_layer_type': 'WMS',  # OSM or WMS
-            'projection': 'EPSG:28992',  # EPSG:900913, EPSG:28992
-            'display_projection': 'EPSG:28992',  # EPSG:900913/28992/4326
-            'startlocation_x': '144000',
-            'startlocation_y': '486000',
-            'startlocation_zoom': '4',
-            'base_layer_wms': (
-                'http://kaart.almere.nl/wmsconnector/com.esri.wms.Esrimap?'
-                'SERVICENAME=AIKWMS&'),
-            'base_layer_wms_layers': (
-                'mrsid2008'),
-            }
-        map_settings = lizard_map.coordinates.MapSettings(MAP_SETTINGS)
-        self.assertTrue(map_settings.mapnik_projection(),
-                        lizard_map.coordinates.RD)
-        self.assertTrue(map_settings.srid, 28992)
+    # def test_map_settings2(self):
+    #     """
+    #     Test custom settings for MapSettings.
+    #     """
+
+    #     MAP_SETTINGS = {
+    #         'base_layer_type': 'WMS',  # OSM or WMS
+    #         'projection': 'EPSG:28992',  # EPSG:900913, EPSG:28992
+    #         'display_projection': 'EPSG:28992',  # EPSG:900913/28992/4326
+    #         'startlocation_x': '144000',
+    #         'startlocation_y': '486000',
+    #         'startlocation_zoom': '4',
+    #         'base_layer_wms': (
+    #             'http://kaart.almere.nl/wmsconnector/com.esri.wms.Esrimap?'
+    #             'SERVICENAME=AIKWMS&'),
+    #         'base_layer_wms_layers': (
+    #             'mrsid2008'),
+    #         }
+    #     map_settings = lizard_map.coordinates.MapSettings(MAP_SETTINGS)
+    #     self.assertTrue(map_settings.mapnik_projection(),
+    #                     lizard_map.coordinates.RD)
+    #     self.assertTrue(map_settings.srid, 28992)
 
     def test_srs_to_google(self):
         x, y = lizard_map.coordinates.srs_to_google(
@@ -1141,25 +976,27 @@ class DateRangeStore(unittest.TestCase):
 
         session = {}
 
-        date_range = { 'period': PERIOD_DAY }
+        date_range = {'period': PERIOD_DAY}
         compute_and_store_start_end(session, date_range)
         self.assertEqual(PERIOD_DAY, session[SESSION_DT_PERIOD])
 
-        date_range = { 'period': PERIOD_OTHER }
+        date_range = {'period': PERIOD_OTHER}
         compute_and_store_start_end(session, date_range)
         self.assertEqual(PERIOD_OTHER, session[SESSION_DT_PERIOD])
 
     def test_b(self):
         """Test only the computed values are stored."""
 
-        session = { SESSION_DT_START: datetime.datetime(2011, 8, 1),
-                    SESSION_DT_END: datetime.datetime(2011, 8, 30) }
+        session = {SESSION_DT_START: datetime.datetime(2011, 8, 1),
+                   SESSION_DT_END: datetime.datetime(2011, 8, 30)}
 
-        date_range = { 'period': PERIOD_DAY }
+        date_range = {'period': PERIOD_DAY}
         compute_and_store_start_end(session, date_range)
 
-        self.assertEqual(datetime.datetime(2011, 8, 1), session[SESSION_DT_START])
-        self.assertEqual(datetime.datetime(2011, 8, 30), session[SESSION_DT_END])
+        self.assertEqual(datetime.datetime(2011, 8, 1),
+                         session[SESSION_DT_START])
+        self.assertEqual(datetime.datetime(2011, 8, 30),
+                         session[SESSION_DT_END])
 
     def test_c(self):
         """Test the start and end datetime are stored for PERIOD_OTHER.
@@ -1169,14 +1006,16 @@ class DateRangeStore(unittest.TestCase):
         """
         session = {}
 
-        date_range = { 'period': PERIOD_OTHER,
-                       'dt_start': datetime.datetime(2011, 8, 1),
-                       'dt_end': datetime.datetime(2011, 8, 30) }
+        date_range = {'period': PERIOD_OTHER,
+                      'dt_start': datetime.datetime(2011, 8, 1),
+                      'dt_end': datetime.datetime(2011, 8, 30)}
 
         compute_and_store_start_end(session, date_range)
 
-        self.assertEqual(datetime.datetime(2011, 8, 1), session[SESSION_DT_START])
-        self.assertEqual(datetime.datetime(2011, 8, 30), session[SESSION_DT_END])
+        self.assertEqual(datetime.datetime(2011, 8, 1),
+                         session[SESSION_DT_START])
+        self.assertEqual(datetime.datetime(2011, 8, 30),
+                         session[SESSION_DT_END])
 
     def test_d(self):
         """Test the function stores the correct defaults for PERIOD_OTHER.
@@ -1186,7 +1025,7 @@ class DateRangeStore(unittest.TestCase):
         """
         session = {}
 
-        date_range = { 'period': PERIOD_OTHER }
+        date_range = {'period': PERIOD_OTHER}
         now = datetime.datetime(2011, 8, 30)
         compute_and_store_start_end(session, date_range, now=now)
 
@@ -1196,19 +1035,21 @@ class DateRangeStore(unittest.TestCase):
     def test_e(self):
         """Test the start stored for PERIOD_OTHER is never after the end.
 
-        The required information is stored in the form but the start is after the end.
+        The required information is stored in the form but the start is after
+        the end.
 
         """
         session = {}
 
-        date_range = { 'period': PERIOD_OTHER,
-                       'dt_start': datetime.datetime(2011, 8, 30),
-                       'dt_end': datetime.datetime(2011, 8, 1) }
+        date_range = {'period': PERIOD_OTHER,
+                      'dt_start': datetime.datetime(2011, 8, 30),
+                      'dt_end': datetime.datetime(2011, 8, 1)}
 
         compute_and_store_start_end(session, date_range)
 
-        self.assertEqual(datetime.datetime(2011, 8, 30), session[SESSION_DT_START])
-        self.assertEqual(datetime.datetime(2011, 8, 30), session[SESSION_DT_END])
+        self.assertEqual(datetime.datetime(2011, 8, 30),
+                         session[SESSION_DT_START])
+        self.assertTrue(session[SESSION_DT_START] < session[SESSION_DT_END])
 
 
 class DateRangeRetrieveSet(unittest.TestCase):
@@ -1239,7 +1080,7 @@ class DateRangeRetrieveSet(unittest.TestCase):
         The sessions specifies the required information.
 
         """
-        self.request.session = { SESSION_DT_PERIOD: PERIOD_DAY }
+        self.request.session = {SESSION_DT_PERIOD: PERIOD_DAY}
 
         start, end = current_start_end_dates(self.request, today=self.today)
 
@@ -1258,4 +1099,3 @@ class DateRangeRetrieveSet(unittest.TestCase):
 
         self.assertEqual(start, default_start(self.today))
         self.assertEqual(end, default_end(self.today))
-
